@@ -4,7 +4,7 @@
 class CancelTest: public QpThread {
     public:
 	~CancelTest() { Join();}
-	void Main() {
+	virtual void Main() {
 		try {
 			cout << "Cancel Test" << endl;
 			while (1) {
