@@ -3,8 +3,8 @@
 
 class CreateTest: public QpThread {
     public:
-	~CreateTest() {Join();}
-	void Main() {
+	virtual ~CreateTest() {Join();}
+	virtual void Main() {
 		cout << "x ";
 		cout.flush();
 		Yield();
