@@ -37,6 +37,11 @@ union QpRegItem {
 	unsigned int 	unr;
 };
 
+void reltime_to_abs(const struct timespec *ts_rel, struct timespec *ts_abs);
+void msectime_to_ts(unsigned int msec, struct timespec *ts_rel);
+
+
+int set_fd_flags(int fd, int flags, int mask);
 
 
 extern "C" {
@@ -53,9 +58,9 @@ void do_exit(const char *fmt, ...);
 }
 
 #define QPERR(x) { \
-	int retval; \
-	if ((retval = (x)) < 0) { \
-		__QPERR(retval, x); \
+	int retvaltemp; \
+	if ((retvaltemp = (x)) < 0) { \
+		__QPERR(retvaltemp, x); \
 	} \
 }
 
